pub struct ListDatabasesPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListDatabasesPaginator
This is created with .items()
Implementations
Sourceimpl ListDatabasesPaginatorItems
impl ListDatabasesPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<Database, SdkError<ListDatabasesError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<Database, SdkError<ListDatabasesError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().